@@ -11,10 +11,12 @@ interface ApolloNetworkInterface {
 class ActionCableSubscriber {
   _cable: Consumer
   _networkInterface: ApolloNetworkInterface
+  _channelName: string
 
-  constructor(cable: Consumer, networkInterface: ApolloNetworkInterface) {
+  constructor(cable: Consumer, networkInterface: ApolloNetworkInterface, channelName?: string) {
     this._cable = cable
     this._networkInterface = networkInterface
+    this._channelName = channelName || "GraphqlChannel"
   }
 
   /**
@@ -31,7 +33,7 @@ class ActionCableSubscriber {
     // unique-ish
     var channelId = Math.round(Date.now() + Math.random() * 100000).toString(16)
     var channel = this._cable.subscriptions.create({
-      channel: "GraphqlChannel",
+      channel: this._channelName,
       channelId: channelId,
     }, {
       // After connecting, send the data over ActionCable
@@ -58,13 +60,13 @@ class ActionCableSubscriber {
       // - more: true if this channel should stay open
       // - result: the GraphQL response for this result
       received: function(payload) {
-        if (!payload.more) {
-          registry.unsubscribe(id)
-        }
         var result = payload.result
         if (result) {
           handler(result.errors, result.data)
         }
+        if (!payload.more) {
+          registry.unsubscribe(id)
+        }
       },
     })
     var id = registry.add(channel)
