@@ -91,6 +91,10 @@ class PusherLink extends ApolloLink {
         if (subscriptionChannel) {
           // Set up the pusher subscription for updates from the server
           const pusherChannel = this.pusher.subscribe(subscriptionChannel)
+          // Pass along the initial payload:
+          if (data.data && Object.keys(data.data).length > 0) {
+            observer.next(data)
+          }
           // Subscribe for more update
           pusherChannel.bind("update", (payload: any) => {
             this._onUpdate(subscriptionChannel, observer, payload)
