@@ -8,8 +8,17 @@ interface AblyHandlerOptions {
   fetchOperation: Function
 }
 
+interface GraphQLError {
+  message: string
+  path: (string | number)[]
+  locations: number[][]
+  extensions?: object
+}
+
+type OnErrorData = AblyError | Error| GraphQLError[]
+
 interface ApolloObserver {
-  onError: Function
+  onError: (err: OnErrorData) => void
   onNext: Function
   onCompleted: Function
 }
@@ -50,7 +59,7 @@ function createAblyHandler(options: AblyHandlerOptions) {
   ) => {
     let channel: Types.RealtimeChannelCallbacks | null = null
 
-    const dispatchResult = (result: { errors: any; data: any }) => {
+    const dispatchResult = (result: { errors?: GraphQLError[]; data: any }) => {
       if (result) {
         if (result.errors) {
           // What kind of error stuff belongs here?
@@ -140,7 +149,7 @@ function createAblyHandler(options: AblyHandlerOptions) {
         // (In that case, we want to make sure the channel is cleaned up properly.)
         dispatchResult(response.body)
       } catch (error) {
-        observer.onError(error)
+        observer.onError(error as Error)
       }
     })()
 
@@ -181,11 +190,11 @@ function createAblyHandler(options: AblyHandlerOptions) {
             ably.channels.release(disposedChannel.name)
           }
         } catch (error) {
-          observer.onError(error)
+          observer.onError(error as Error)
         }
       }
     }
   }
 }
 
-export { createAblyHandler, AblyHandlerOptions }
+export { createAblyHandler, AblyHandlerOptions, OnErrorData }
