@@ -12,8 +12,10 @@ module Graphql
       desc "Create a GraphQL::ScalarType with the given name"
       source_root File.expand_path('../templates', __FILE__)
 
-      def create_type_file
-        template "scalar.erb", "#{options[:directory]}/types/#{type_file_name}.rb"
+      private
+
+      def graphql_type
+        "scalar"
       end
     end
   end
