@@ -42,8 +42,8 @@ This is probably a bug in GraphQL-Ruby, please report this error on GitHub: http
   # Turn a query string or schema definition into an AST
   # @param graphql_string [String] a GraphQL query string or schema definition
   # @return [GraphQL::Language::Nodes::Document]
-  def self.parse(graphql_string, trace: GraphQL::Tracing::NullTrace)
-    default_parser.parse(graphql_string, trace: trace)
+  def self.parse(graphql_string, trace: GraphQL::Tracing::NullTrace, filename: nil)
+    default_parser.parse(graphql_string, trace: trace, filename: filename)
   end
 
   # Read the contents of `filename` and parse them as GraphQL
@@ -60,6 +60,7 @@ This is probably a bug in GraphQL-Ruby, please report this error on GitHub: http
   end
 
   def self.parse_with_racc(string, filename: nil, trace: GraphQL::Tracing::NullTrace)
+    warn "`GraphQL.parse_with_racc` is deprecated; GraphQL-Ruby no longer uses racc for parsing. Call `GraphQL.parse` or `GraphQL::Language::Parser.parse` instead."
     GraphQL::Language::Parser.parse(string, filename: filename, trace: trace)
   end
 
