@@ -7,11 +7,11 @@ module GraphQL
                   "InputObject are represented as Input Values which describe their type and "\
                   "optionally a default value."
       field :name, String, null: false
-      field :description, String, null: true
+      field :description, String
       field :type, GraphQL::Schema::LateBoundType.new("__Type"), null: false
-      field :default_value, String, "A GraphQL-formatted string representing the default value for this input value.", null: true
+      field :default_value, String, "A GraphQL-formatted string representing the default value for this input value."
       field :is_deprecated, Boolean, null: false
-      field :deprecation_reason, String, null: true
+      field :deprecation_reason, String
 
       def is_deprecated
         !!@object.deprecation_reason
@@ -23,6 +23,12 @@ module GraphQL
           if value.nil?
             'null'
           else
+            if (@object.type.kind.list? || (@object.type.kind.non_null? && @object.type.of_type.kind.list?)) && !value.respond_to?(:map)
+              # This is a bit odd -- we expect the default value to be an application-style value, so we use coerce result below.
+              # But coerce_result doesn't wrap single-item lists, which are valid inputs to list types.
+              # So, apply that wrapper here if needed.
+              value = [value]
+            end
             coerced_default_value = @object.type.coerce_result(value, @context)
             serialize_default_value(coerced_default_value, @object.type)
           end
@@ -48,7 +54,7 @@ module GraphQL
         elsif type.kind.input_object?
           "{" +
             value.map do |k, v|
-              arg_defn = type.arguments[k]
+              arg_defn = type.get_argument(k, context)
               "#{k}: #{serialize_default_value(v, arg_defn.type)}"
             end.join(", ") +
             "}"
