@@ -71,14 +71,11 @@ module GraphQL
           elsif inherited_extras
             inherited_extras
           else
-            NO_EXTRAS
+            GraphQL::EmptyObjects::EMPTY_ARRAY
           end
         end
       end
 
-      NO_EXTRAS = [].freeze
-      private_constant :NO_EXTRAS
-
       # Called when this extension is attached to a field.
       # The field definition may be extended during this method.
       # @return [void]
