@@ -50,7 +50,7 @@ module GraphQL
             if loads && arg_defn.type.list?
               class_eval <<-RUBY, __FILE__, __LINE__ + 1
               def #{method_owner}load_#{arg_defn.keyword}(values, context = nil)
-                argument = get_argument("#{arg_defn.graphql_name}")
+                argument = get_argument("#{arg_defn.graphql_name}", context || self.context)
                 (context || self.context).query.after_lazy(values) do |values2|
                   GraphQL::Execution::Lazy.all(values2.map { |value| load_application_object(argument, value, context || self.context) })
                 end
@@ -59,7 +59,7 @@ module GraphQL
             elsif loads
               class_eval <<-RUBY, __FILE__, __LINE__ + 1
               def #{method_owner}load_#{arg_defn.keyword}(value, context = nil)
-                argument = get_argument("#{arg_defn.graphql_name}")
+                argument = get_argument("#{arg_defn.graphql_name}", context || self.context)
                 load_application_object(argument, value, context || self.context)
               end
               RUBY
