@@ -20,7 +20,17 @@ module GraphQL
           @payload_type ||= generate_payload_type
         end
 
-        alias :type :payload_type
+        def type(new_type = nil, null: nil)
+          if new_type
+            payload_type(new_type)
+            if !null.nil?
+              self.null(null)
+            end
+          else
+            super()
+          end
+        end
+
         alias :type_expr :payload_type
 
         def field_class(new_class = nil)
@@ -79,16 +89,16 @@ module GraphQL
         def generate_payload_type
           resolver_name = graphql_name
           resolver_fields = all_field_definitions
-          Class.new(object_class) do
-            graphql_name("#{resolver_name}Payload")
-            description("Autogenerated return type of #{resolver_name}")
-            resolver_fields.each do |f|
-              # Reattach the already-defined field here
-              # (The field's `.owner` will still point to the mutation, not the object type, I think)
-              # Don't re-warn about a method conflict. Since this type is generated, it should be fixed in the resolver instead.
-              add_field(f, method_conflict_warning: false)
-            end
+          pt = Class.new(object_class)
+          pt.graphql_name("#{resolver_name}Payload")
+          pt.description("Autogenerated return type of #{resolver_name}.")
+          resolver_fields.each do |f|
+            # Reattach the already-defined field here
+            # (The field's `.owner` will still point to the mutation, not the object type, I think)
+            # Don't re-warn about a method conflict. Since this type is generated, it should be fixed in the resolver instead.
+            pt.add_field(f, method_conflict_warning: false)
           end
+          pt
         end
       end
     end
