@@ -9,7 +9,7 @@ module GraphQL
       # @return [String] Corresponds to the Subscription root field name
       attr_reader :name
 
-      # @return [GraphQL::Query::Arguments]
+      # @return [GraphQL::Execution::Interpreter::Arguments]
       attr_reader :arguments
 
       # @return [GraphQL::Query::Context]
@@ -37,7 +37,7 @@ module GraphQL
       end
 
       # @return [String] an identifier for this unit of subscription
-      def self.serialize(_name, arguments, field, scope:, context: GraphQL::Query::NullContext)
+      def self.serialize(_name, arguments, field, scope:, context: GraphQL::Query::NullContext.instance)
         subscription = field.resolver || GraphQL::Schema::Subscription
         normalized_args = stringify_args(field, arguments.to_h, context)
         subscription.topic_for(arguments: normalized_args, field: field, scope: scope)
@@ -100,13 +100,8 @@ module GraphQL
               arg_name = k.to_s
               camelized_arg_name = GraphQL::Schema::Member::BuildType.camelize(arg_name)
               arg_defn = get_arg_definition(arg_owner, camelized_arg_name, context)
-
-              if arg_defn
-                normalized_arg_name = camelized_arg_name
-              else
-                normalized_arg_name = arg_name
-                arg_defn = get_arg_definition(arg_owner, normalized_arg_name, context)
-              end
+              arg_defn ||= get_arg_definition(arg_owner, arg_name, context)
+              normalized_arg_name = arg_defn.graphql_name
               arg_base_type = arg_defn.type.unwrap
               # In the case where the value being emitted is seen as a "JSON"
               # type, treat the value as one atomic unit of serialization
@@ -131,7 +126,13 @@ module GraphQL
           when GraphQL::Schema::InputObject
             stringify_args(arg_owner, args.to_h, context)
           else
-            args
+            if arg_owner.is_a?(Class) && arg_owner < GraphQL::Schema::Enum
+              # `prepare:` may have made the value something other than
+              # a defined value of this enum -- use _that_ in this case.
+              arg_owner.coerce_isolated_input(args) || args
+            else
+              args
+            end
           end
         end
 
