@@ -151,4 +151,29 @@ describe GraphQL::Analysis::AST::MaxQueryDepth do
       assert_equal ["This query is too large to execute."], execute_result["errors"].map { |err| err["message"] }
     end
   end
+
+  it "counts introspection fields by default, but can be set to skip" do
+    schema.max_depth = 3
+    query_str = <<-GRAPHQL
+    {
+      __type(name: \"Abc\") {
+        fields {
+          type {
+            ofType {
+              name
+            }
+          }
+        }
+      }
+    }
+    GRAPHQL
+
+    result = schema.execute(query_str)
+    assert_equal ["Query has depth of 5, which exceeds max depth of 3"], result["errors"].map { |e| e["message"] }
+
+    schema.max_depth(3, count_introspection_fields: false)
+
+    result = schema.execute(query_str)
+    assert_equal({ "__type" => nil }, result["data"])
+  end
 end
