@@ -522,6 +522,11 @@ describe GraphQL::Analysis::AST::QueryComplexity do
         field :name, String
       end
 
+      class CustomThingConnection < GraphQL::Types::Relay::BaseConnection
+        edge_type Thing.edge_type
+        field :something_special, String, complexity: 3
+      end
+
       class Query < GraphQL::Schema::Object
         field :complexity, SingleComplexity do
           argument :int_value, Int, required: false
@@ -541,6 +546,17 @@ describe GraphQL::Analysis::AST::QueryComplexity do
         def things(count:)
           count.times.map {|t| {name: t.to_s}}
         end
+
+        class ThingsCustom < GraphQL::Schema::Resolver
+          type CustomThingConnection, null: false
+          complexity 100
+
+          def resolve
+            5.times { |t| { name: "Thing #{t}" } }
+          end
+        end
+
+        field :things_custom, resolver: ThingsCustom
       end
 
       query(Query)
@@ -599,6 +615,15 @@ describe GraphQL::Analysis::AST::QueryComplexity do
         assert_equal 102, complexity, "It uses max page size"
       end
     end
+
+    describe "when connection fields have custom complexity" do
+      let(:query_string) { "{ thingsCustom(first: 2) { somethingSpecial nodes { name } } }"}
+
+      it "uses the custom configured value" do
+        complexity = reduce_result.first
+        assert_equal 106, complexity
+      end
+    end
   end
 
   describe "field_complexity hook" do
