@@ -24,11 +24,13 @@ describe GraphQL::Backtrace do
     def inspect; nil; end
   end
 
-  class ErrorInstrumentation
-    def self.before_query(_query)
+  module ErrorTrace
+    def initialize(required_arg:, **_rest)
+      super(**_rest)
     end
 
-    def self.after_query(query)
+    def execute_multiplex(multiplex:)
+      super
       raise "Instrumentation Boom"
     end
   end
@@ -146,7 +148,7 @@ describe GraphQL::Backtrace do
       assert_includes err.message, "\n" + rendered_table
       # The message includes the original error message
       assert_includes err.message, "This is broken: Boom"
-      assert_includes err.message, "spec/graphql/backtrace_spec.rb:47", "It includes the original backtrace"
+      assert_includes err.message, "spec/graphql/backtrace_spec.rb:49", "It includes the original backtrace"
       assert_includes err.message, "more lines"
     end
 
@@ -211,7 +213,7 @@ describe GraphQL::Backtrace do
 
     it "raises original exception instead of a TracedError when error does not occur during resolving" do
       instrumentation_schema = Class.new(schema) do
-        instrument(:query, ErrorInstrumentation)
+        trace_with(ErrorTrace, required_arg: true)
       end
 
       assert_raises(RuntimeError) {
