@@ -306,9 +306,9 @@ describe GraphQL::Execution::Interpreter do
       end
       tracer EnsureArgsAreObject
 
-      class EnsureThreadCleanedUp
-        def self.before_multiplex(_multiplex); end
-        def self.after_multiplex(multiplex)
+      module EnsureThreadCleanedUp
+        def execute_multiplex(multiplex:)
+          res = super
           runtime_info = Thread.current[:__graphql_runtime_info]
           if !runtime_info.nil? && runtime_info != {}
             if !multiplex.context[:allow_pending_thread_state]
@@ -316,10 +316,10 @@ describe GraphQL::Execution::Interpreter do
               raise "Query did not clean up runtime state, found: #{runtime_info.inspect}"
             end
           end
+          res
         end
       end
-
-      instrument :multiplex, EnsureThreadCleanedUp
+      trace_with(EnsureThreadCleanedUp)
     end
   end
 
@@ -480,6 +480,19 @@ describe GraphQL::Execution::Interpreter do
       assert_nil Thread.current[:__graphql_runtime_info]
     end
 
+    it "places errors ahead of data in the response" do
+      query_str = <<-GRAPHQL
+      {
+        expansion(sym: "XYZ") {
+          name
+        }
+      }
+      GRAPHQL
+
+      res = InterpreterTest::Schema.execute(query_str)
+      assert_equal ["errors", "data"], res.keys
+    end
+
     it "propagates nulls in lists" do
       query_str = <<-GRAPHQL
       {
