@@ -4,7 +4,7 @@ require "spec_helper"
 describe GraphQL::Pagination::ArrayConnection do
   ARRAY_ITEMS = ConnectionAssertions::NAMES.map { |n| { name: n } }
 
-  class ArrayConnectionWithTotalCount < GraphQL::Pagination::ArrayConnection
+  class ArrayTestConnectionWithTotalCount < GraphQL::Pagination::ArrayConnection
     def total_count
       items.size
     end
@@ -13,7 +13,7 @@ describe GraphQL::Pagination::ArrayConnection do
   let(:schema) {
     ConnectionAssertions.build_schema(
       connection_class: GraphQL::Pagination::ArrayConnection,
-      total_count_connection_class: ArrayConnectionWithTotalCount,
+      total_count_connection_class: ArrayTestConnectionWithTotalCount,
       get_items: -> { ARRAY_ITEMS }
     )
   }
