@@ -46,7 +46,7 @@ describe GraphQL::Schema::Argument do
           raise GraphQL::UnauthorizedError.new('no access')
         end
 
-        argument :keys, [String], required: false, method_access: false
+        argument :keys, [String], required: false
         argument :instrument_id, ID, required: false, loads: Jazz::InstrumentType
         argument :instrument_ids, [ID], required: false, loads: Jazz::InstrumentType
 
@@ -92,6 +92,10 @@ describe GraphQL::Schema::Argument do
         -> { Jazz::GloballyIdentifiableType.find(id) }
       end
 
+      def self.resolve_type(type, obj, ctx)
+        -> { type } # just for `loads:`
+      end
+
       orphan_types [Jazz::InstrumentType, UnauthorizedInstrumentType]
     end
   end
@@ -349,6 +353,13 @@ describe GraphQL::Schema::Argument do
     it "has an assignment method" do
       arg.deprecation_reason = "another new deprecation reason"
       assert_equal "another new deprecation reason", arg.deprecation_reason
+      assert_equal 1, arg.directives.size
+      arg.deprecation_reason = "something else"
+      assert_equal "something else", arg.deprecation_reason
+      assert_equal 1, arg.directives.size
+      arg.deprecation_reason = nil
+      assert_nil arg.deprecation_reason
+      assert_equal 0, arg.directives.size
     end
 
     it "disallows deprecating required arguments in the constructor" do
@@ -635,6 +646,21 @@ describe GraphQL::Schema::Argument do
     end
   end
 
+  it "can get default_value and prepare from method calls in the config block" do
+    type = Class.new(GraphQL::Schema::Object) do
+      field :f, String do
+        argument :arg, String do
+          default_value "blah"
+          prepare -> { :stuff }
+        end
+      end
+    end
+
+    arg = type.get_field("f").get_argument("arg")
+    assert_equal "blah", arg.default_value
+    assert_equal :stuff, arg.prepare.call
+  end
+
   describe "multiple argument definitions with default values" do
     class MultipleArgumentDefaultValuesSchema < GraphQL::Schema
       class BaseArgument < GraphQL::Schema::Argument
@@ -681,4 +707,46 @@ describe GraphQL::Schema::Argument do
       assert_equal "method-default", get_echo_for(:visible_4) # no match
     end
   end
+
+  describe "multiple argument validations with rescue_from" do
+    let(:schema) do
+      Class.new(GraphQL::Schema) do
+        rescue_from(StandardError) do |exception, _obj, _args, _context, _field|
+          raise exception
+        end
+
+        query_type = Class.new(GraphQL::Schema::Object) do
+          graphql_name 'TestQueryType'
+
+          field :test, Integer, null: false do
+            argument :a, Integer, validates: { numericality: { greater_than_or_equal_to: 1 } }
+            argument :b, Integer, validates: { numericality: { greater_than_or_equal_to: 1 } }
+          end
+
+          def test; end
+        end
+
+        query(query_type)
+        lazy_resolve(Proc, :call)
+      end
+    end
+
+    it 'validates both arguments' do
+      expected_errors = [
+        {
+          "message"=>"a must be greater than or equal to 1",
+          "locations"=>[{ "line"=>1, "column"=>3 }],
+          "path"=>["test"]
+        },
+        {
+          "message"=>"b must be greater than or equal to 1",
+          "locations"=>[{"line"=>1, "column"=>3}],
+          "path"=>["test"]
+        }
+      ]
+      query = "{ test(a: -4, b: -5) }"
+
+      assert_equal expected_errors, schema.execute(query).to_h['errors']
+    end
+  end
 end
