@@ -18,12 +18,15 @@ schema {
   query: HelloScalars
 }
 
+type EmptyType
+
 type HelloScalars {
   bool: Boolean
   float: Float
   id: ID
   int: Int
   str: String!
+  t: EmptyType
 }
       SCHEMA
 
@@ -74,10 +77,11 @@ directive @hashed repeatable on FIELD_DEFINITION | INPUT_FIELD_DEFINITION
 
 directive @language(is: String!) on ENUM_VALUE
 
-type Hello implements Secret @greeting {
+type Hello implements Secret & Secret2 @greeting {
   goodbye(saying: Parting @greeting): Parting
   humbug: Int @greeting(pleasant: false)
   password: Phrase @hashed
+  password2: String
   str(in: Input): String
 }
 
@@ -92,8 +96,13 @@ enum Parting @greeting {
 
 union Phrase @greeting = Hello | Word
 
-interface Secret @greeting @greeting2 {
+interface Secret implements Secret2 @greeting @greeting2 {
   password: String
+  password2: String
+}
+
+interface Secret2 {
+  password2: String
 }
 
 type Word {
@@ -103,7 +112,7 @@ type Word {
 
       parsed_schema = GraphQL::Schema.from_definition(schema)
       hello_type = parsed_schema.get_type("Hello")
-      assert_equal ["deprecated", "foo", "greeting", "greeting2", "hashed", "include", "language", "skip"], parsed_schema.directives.keys.sort
+      assert_equal ["deprecated", "foo", "greeting", "greeting2", "hashed", "include", "language", "oneOf", "skip", "specifiedBy"], parsed_schema.directives.keys.sort
       parsed_schema.directives.values.each do |dir_class|
         assert dir_class < GraphQL::Schema::Directive
       end
@@ -200,7 +209,8 @@ union U = Hello
 
       assert_schema_and_compare_output(schema)
 
-      built_schema = GraphQL::Schema.from_definition(schema)
+      # TODO: GraphQL::CParser doesn't support definition_line yet.
+      built_schema = GraphQL::Schema.from_definition(schema, parser: GraphQL::Language::Parser)
       # The schema's are the same since there's no description
       assert_equal 1, built_schema.ast_node.line
       assert_equal 1, built_schema.ast_node.definition_line
@@ -265,7 +275,7 @@ type Hello {
       SCHEMA
 
       built_schema = GraphQL::Schema.from_definition(schema)
-      assert_equal ['deprecated', 'include', 'skip'], built_schema.directives.keys.sort
+      assert_equal ['deprecated', 'include', 'oneOf', 'skip', 'specifiedBy'], built_schema.directives.keys.sort
     end
 
     it 'supports overriding built-in directives' do
@@ -285,9 +295,9 @@ type Hello {
 
       built_schema = GraphQL::Schema.from_definition(schema)
 
-      refute built_schema.directives['skip'] == GraphQL::Directive::SkipDirective
-      refute built_schema.directives['include'] == GraphQL::Directive::IncludeDirective
-      refute built_schema.directives['deprecated'] == GraphQL::Directive::DeprecatedDirective
+      refute built_schema.directives['skip'] == GraphQL::Schema::Directive::Skip
+      refute built_schema.directives['include'] == GraphQL::Schema::Directive::Include
+      refute built_schema.directives['deprecated'] == GraphQL::Schema::Directive::Deprecated
     end
 
     it 'supports adding directives while maintaining built-in directives' do
@@ -556,6 +566,36 @@ type Thing implements Named & Node {
       assert_schema_and_compare_output(schema)
     end
 
+    it "only adds the interface to the type once" do
+      schema = <<-SCHEMA
+interface Named implements Node {
+  id: ID
+  name: String
+}
+
+interface Node {
+  id: ID
+}
+
+type Query {
+  thing: Thing
+}
+
+type Thing implements Named & Node & Timestamped {
+  id: ID
+  name: String
+  timestamp: String
+}
+
+interface Timestamped implements Node {
+  id: ID
+  timestamp: String
+}
+      SCHEMA
+
+      assert_schema_and_compare_output(schema)
+    end
+
     it 'supports simple output enum' do
       schema = <<-SCHEMA
 schema {
@@ -885,6 +925,8 @@ directive @Directive (
   argument: String
 ) on SCHEMA
 
+directive @custom(thing: Boolean) on SCHEMA
+
 type Type implements Interface {
   field(argument: String): String
 }
@@ -910,7 +952,7 @@ type Type implements Interface {
       assert_equal [23, 3], schema.types["Input"].arguments["argument"].ast_node.position
       assert_equal [26, 1], schema.directives["Directive"].ast_node.position
       assert_equal [28, 3], schema.directives["Directive"].arguments["argument"].ast_node.position
-      assert_equal [31, 22], schema.types["Type"].ast_node.interfaces[0].position
+      assert_equal [33, 22], schema.types["Type"].ast_node.interfaces[0].position
     end
 
     it 'can build a schema from a file path' do
@@ -989,21 +1031,6 @@ SCHEMA
       assert_equal 'Must provide schema definition with query type or a type named Query.', err.message
     end
 
-    it 'Requires a query type that defines at least one field' do
-      schema = <<-SCHEMA
-schema {
-  query: Hello
-}
-
-type Hello { }
-SCHEMA
-
-      err = assert_raises(GraphQL::Schema::InvalidTypeError) do
-        GraphQL::Schema.from_definition(schema).to_graphql(silence_deprecation_warning: true)
-      end
-      assert_equal 'Hello is invalid: Hello must define at least 1 field. 0 defined.', err.message
-    end
-
     it 'Unknown type referenced' do
       schema = <<-SCHEMA
 schema {
@@ -1510,4 +1537,219 @@ type ReachableType implements Node {
       assert_equal expected_definition, schema.to_definition, "UnreachableType is excluded"
     end
   end
+
+  it "works with indirect interface implementation" do
+    schema_string = <<~GRAPHQL
+      type Query {
+        entities: [Entity!]!
+        person: Person
+      }
+
+      type Person implements NamedEntity {
+        id: ID!
+        name: String
+        nationality: String
+      }
+
+      type Product implements NamedEntity {
+        id: ID!
+        name: String
+        amount: Int
+      }
+
+      interface NamedEntity implements Entity {
+        id: ID!
+        name: String
+      }
+
+      type Payment implements Entity {
+        id: ID!
+        amount: Int
+      }
+
+      interface Entity {
+        id: ID!
+      }
+    GRAPHQL
+
+    schema = GraphQL::Schema.from_definition(schema_string)
+
+    assert_equal ["amount", "id"], schema.types.fetch("Payment").fields.keys.sort
+    assert_equal ["id", "name", "nationality"], schema.types.fetch("Person").fields.keys.sort
+  end
+
+  it "supports extending schemas with directives" do
+    schema_sdl = <<~EOS
+    extend schema
+      @link(import: ["@key", "@shareable"], url: "https://specs.apollo.dev/federation/v2.0")
+
+    directive @link(as: String, for: link__Purpose, import: [link__Import], url: String!) repeatable on SCHEMA
+
+    type Query {
+      something: Int
+    }
+
+    scalar link__Import
+
+    enum link__Purpose {
+      EXECUTION
+      SECURITY
+    }
+    EOS
+
+    schema = GraphQL::Schema.from_definition(schema_sdl)
+    assert_equal ["link"], schema.schema_directives.map(&:graphql_name)
+    assert_equal({ url: "https://specs.apollo.dev/federation/v2.0", import: ["@key", "@shareable"] },
+      schema.schema_directives.first.arguments.to_h)
+
+    assert_equal schema_sdl, schema.to_definition
+  end
+
+
+  it "supports extending schemas with directives" do
+    schema_sdl = <<~EOS
+      extend schema
+        @link(url: "https://specs.apollo.dev/federation/v2.0",
+              import: ["@key", "@shareable"])
+
+      type Query {
+        something: Int
+      }
+    EOS
+
+    class LinkSchema < GraphQL::Schema
+      class Import < GraphQL::Schema::Scalar
+      end
+
+      class Purpose < GraphQL::Schema::Scalar
+      end
+
+      class Link < GraphQL::Schema::Directive
+        argument :url, String
+        argument :as, String, required: false
+        argument :import, Import, required: false
+        argument :for, Purpose, required: false
+
+        repeatable(true)
+        locations SCHEMA
+      end
+
+      directive(Link)
+    end
+
+    assert_equal LinkSchema::Link, LinkSchema.directives["link"]
+    schema = LinkSchema.from_definition(schema_sdl)
+    assert_equal ["link"], schema.schema_directives.map(&:graphql_name)
+    assert_equal({ url: "https://specs.apollo.dev/federation/v2.0", import: ["@key", "@shareable"] },
+      schema.schema_directives.first.arguments.to_h)
+
+    expected_schema = <<~GRAPHQL
+      extend schema
+        @link(url: "https://specs.apollo.dev/federation/v2.0", import: ["@key", "@shareable"])
+
+      directive @link(as: String, for: Purpose, import: Import, url: String!) repeatable on SCHEMA
+
+      scalar Import
+
+      scalar Purpose
+
+      type Query {
+        something: Int
+      }
+    GRAPHQL
+    assert_equal expected_schema, schema.to_definition
+  end
+
+  describe "JSON type" do
+    class JsonTypeApplication
+      SCHEMA_STRING = <<~EOS
+        scalar JsonValue
+
+        type Query {
+          echoJsonValue(arg: JsonValue): JsonValue
+        }
+      EOS
+
+      def initialize
+        @schema = GraphQL::Schema.from_definition(SCHEMA_STRING, default_resolve: self)
+      end
+
+      def execute_query(query_string, **vars)
+        @schema.execute(query_string, variables: vars)
+      end
+
+      def call(parent_type, field, object, args, context)
+        args.fetch(:arg)
+      end
+
+      def coerce_input(type, value, ctx)
+        nils = ctx[:nils] ||= []
+        if value.is_a?(Array)
+          nils << value[2]
+        else
+          nils << value["abc"]
+        end
+        ::JSON.generate(value)
+      end
+
+      def coerce_result(type, value, ctx)
+        ::JSON.parse(value)
+      end
+    end
+
+    it "Sends normal ruby values to schema coercion" do
+      app = JsonTypeApplication.new
+
+      res_1 = app.execute_query(<<~EOS, arg: [3, "abc", nil, 7])
+        query WithArg($arg: JsonValue) {
+          echoJsonValue(arg: $arg)
+        }
+      EOS
+
+      assert_equal([3, "abc", nil, 7], res_1["data"]["echoJsonValue"])
+      assert_equal [nil, nil], res_1.context[:nils]
+
+      res_2 = app.execute_query(<<~EOS)
+        query {
+          echoJsonValue(arg: [3, "abc", null, 7])
+        }
+      EOS
+      assert_equal([3, "abc", nil, 7], res_2["data"]["echoJsonValue"])
+      assert_equal [nil, nil], res_2.context[:nils]
+
+      res_3 = app.execute_query(<<~EOS, arg: { "abc" => nil, "def" => 7 })
+      query WithArg($arg: JsonValue) {
+        echoJsonValue(arg: $arg)
+      }
+      EOS
+
+      assert_equal({ "abc" => nil, "def" => 7 }, res_3["data"]["echoJsonValue"])
+      assert_equal [nil, nil], res_3.context[:nils]
+
+      res_4 = app.execute_query(<<~EOS)
+      query {
+        echoJsonValue(arg: { abc: null, def: 7, ghi: { jkl: null } })
+      }
+      EOS
+
+      assert_equal({ "abc" => nil, "def" => 7, "ghi"=>{"jkl"=>nil} }, res_4["data"]["echoJsonValue"])
+      assert_equal [nil, nil], res_4.context[:nils]
+    end
+  end
+
+  it "reprints schema with extend when root types match" do
+    schema_str = <<~EOS
+      extend schema
+        @customDirective
+
+      directive @customDirective repeatable on SCHEMA
+
+      type Query {
+        foo: Int
+      }
+    EOS
+
+    schema = GraphQL::Schema.from_definition(schema_str)
+    assert_equal schema_str, schema.to_definition
+  end
 end
