@@ -57,18 +57,6 @@ describe GraphQL::Schema::InputObject do
     end
   end
 
-  describe ".to_graphql" do
-    it "assigns itself as the arguments_class" do
-      assert_equal input_object, input_object.deprecated_to_graphql.arguments_class
-    end
-
-    it "accepts description: kwarg" do
-      input_obj_class = Jazz::InspectableInput
-      input_obj_type = input_obj_class.deprecated_to_graphql
-      assert_equal "Test description kwarg", input_obj_type.arguments["stringValue"].description
-    end
-  end
-
   describe "camelizing with numbers" do
     module InputObjectWithNumbers
       class InputObject < GraphQL::Schema::InputObject
@@ -138,6 +126,24 @@ describe GraphQL::Schema::InputObject do
         end
       end
 
+      class Thing < GraphQL::Schema::Object
+        field :name, String
+      end
+
+      class PreparedInputObj < GraphQL::Schema::InputObject
+        argument :thing_id, ID, loads: Thing, prepare: ->(val, ctx) { "thing-#{val}" }
+      end
+
+      class ResolverPrepares < GraphQL::Schema::Resolver
+        argument :input_object, PreparedInputObj
+        argument :thing_id, ID, loads: Thing, prepare: ->(val, ctx) { "thing-#{val}" }
+        type [String], null: false
+
+        def resolve(thing:, input_object:)
+          [thing.name, input_object[:thing].name]
+        end
+      end
+
       class Query < GraphQL::Schema::Object
         field :inputs, [String], null: false do
           argument :input, InputObj
@@ -146,6 +152,20 @@ describe GraphQL::Schema::InputObject do
         def inputs(input:)
           [input.to_kwargs.inspect, input.instrument.name]
         end
+
+        field :multiple_prepares, [String] do
+          argument :input_object, PreparedInputObj
+          argument :thing_id, ID, loads: Thing, prepare: ->(val, ctx) { "thing-#{val}" }
+        end
+
+        def multiple_prepares(thing:, input_object:)
+          [thing.name, input_object[:thing].name]
+        end
+
+        field :resolver_prepares, resolver: ResolverPrepares
+
+
+        field :t, Thing
       end
 
       class Mutation < GraphQL::Schema::Object
@@ -205,7 +225,13 @@ describe GraphQL::Schema::InputObject do
         lazy_resolve(Proc, :call)
 
         def self.object_from_id(id, ctx)
-          -> { Jazz::GloballyIdentifiableType.find(id) }
+          -> {
+            if id.start_with?("thing-")
+              OpenStruct.new(name: id)
+            else
+              Jazz::GloballyIdentifiableType.find(id)
+            end
+          }
         end
 
         def self.resolve_type(type, obj, ctx)
@@ -217,6 +243,14 @@ describe GraphQL::Schema::InputObject do
       end
     end
 
+    it "always prepares before loading" do
+      res = InputObjectPrepareTest::Schema.execute("{ resolverPrepares(thingId: \"abc\", inputObject: { thingId: \"def\" }) }")
+      assert_equal ["thing-abc", "thing-def"], res["data"]["resolverPrepares"]
+
+      res = InputObjectPrepareTest::Schema.execute("{ multiplePrepares(thingId: \"abc\", inputObject: { thingId: \"def\" }) }")
+      assert_equal ["thing-abc", "thing-def"], res["data"]["multiplePrepares"]
+    end
+
     it "calls methods on the input object" do
       query_str = <<-GRAPHQL
       { inputs(input: { a: 1, b: 2, c: 3, d: 4, e: 5, instrumentId: "Instrument/Drum Kit" }) }
@@ -621,59 +655,6 @@ describe GraphQL::Schema::InputObject do
     end
   end
 
-  describe 'hash conversion behavior' do
-    module InputObjectToHTest
-      class TestInput1 < GraphQL::Schema::InputObject
-        graphql_name "TestInput1"
-        argument :d, Int
-        argument :e, Int
-        argument :instrument_id, ID, loads: Jazz::InstrumentType
-      end
-
-      class TestInput2 < GraphQL::Schema::InputObject
-        graphql_name "TestInput2"
-        argument :a, Int
-        argument :b, Int
-        argument :c, TestInput1, as: :inputObject
-      end
-
-      TestInput1.deprecated_to_graphql
-      TestInput2.deprecated_to_graphql
-    end
-
-    before do
-      arg_values = {a: 1, b: 2, c: { d: 3, e: 4, instrumentId: "Instrument/Drum Kit"}}
-
-      query = GraphQL::Query.new(Jazz::Schema, "{ __typename }")
-      # This is because a test below expects `instrument:` to have been loaded
-      # during `InputObject#initialize`, which only happens when `!context.interpreter?`.
-      # Maybe that test could be updated instead.
-      context_without_interpreter = Class.new(SimpleDelegator) do
-        def interpreter?
-          false
-        end
-      end
-
-      @input_object = InputObjectToHTest::TestInput2.new(
-        arg_values,
-        context: context_without_interpreter.new(query.context),
-        defaults_used: Set.new
-      )
-    end
-
-    describe "#to_h" do
-      it "returns a symbolized, aliased, ruby keyword style hash" do
-        assert_equal({ a: 1, b: 2, input_object: { d: 3, e: 4, instrument: Jazz::Models::Instrument.new("Drum Kit", "PERCUSSION") } }, @input_object.to_h)
-      end
-    end
-
-    describe "#to_hash" do
-      it "returns the same results as #to_h (aliased)" do
-        assert_equal(@input_object.to_h, @input_object.to_hash)
-      end
-    end
-  end
-
   describe "#dig" do
     module InputObjectDigTest
       class TestInput1 < GraphQL::Schema::InputObject
@@ -688,40 +669,33 @@ describe GraphQL::Schema::InputObject do
         argument :b, Int
         argument :c, TestInput1, as: :inputObject
       end
-
-      TestInput1.deprecated_to_graphql
-      TestInput2.deprecated_to_graphql
     end
-    arg_values = {a: 1, b: 2, c: { d: 3, e: 4 }}
+    arg_values = {
+      a: 1,
+      b: 2,
+      inputObject: InputObjectDigTest::TestInput1.new(nil, ruby_kwargs: { d: 3, e: 4 }, context: nil, defaults_used: Set.new)
+    }
 
     input_object = InputObjectDigTest::TestInput2.new(
-      arg_values,
+      nil,
+      ruby_kwargs: arg_values,
       context: nil,
       defaults_used: Set.new
     )
     it "returns the value at that key" do
-      assert_equal 1, input_object.dig("a")
       assert_equal 1, input_object.dig(:a)
-      assert input_object.dig("inputObject").is_a?(GraphQL::Schema::InputObject)
+
+      assert input_object.dig(:inputObject).is_a?(GraphQL::Schema::InputObject)
     end
 
     it "works with nested keys" do
-      assert_equal 3, input_object.dig("inputObject", "d")
       assert_equal 3, input_object.dig(:inputObject, :d)
-      assert_equal 3, input_object.dig("inputObject", :d)
-      assert_equal 3, input_object.dig(:inputObject, "d")
     end
 
     it "returns nil for missing keys" do
       assert_nil input_object.dig("z")
       assert_nil input_object.dig(7)
     end
-
-    it "handles underscored keys" do
-      # TODO - shouldn't this work too?
-      # assert_equal 3, input_object.dig('input_object', 'd')
-      assert_equal 3, input_object.dig(:input_object, :d)
-    end
   end
 
   describe "introspection" do
@@ -748,34 +722,6 @@ describe GraphQL::Schema::InputObject do
     end
   end
 
-  describe "warning for method objects" do
-    it "warns for method conflicts" do
-      input_object = Class.new(GraphQL::Schema::InputObject) do
-        graphql_name "X"
-        argument :method, String
-      end
-
-      expected_warning = "Unable to define a helper for argument with name 'method' as this is a reserved name. Add `method_access: false` to stop this warning."
-
-      messages = []
-      GraphQL::Deprecation.stub(:warn, ->(message) { messages << message; nil }) do
-        input_object.graphql_definition(silence_deprecation_warning: true)
-      end
-      assert_equal [expected_warning], messages
-    end
-
-    it "doesn't warn with `method_access: false`" do
-      input_object = Class.new(GraphQL::Schema::InputObject) do
-        graphql_name "X"
-        argument :method, String, method_access: false
-      end
-
-      assert_output "", "" do
-        input_object.graphql_definition(silence_deprecation_warning: true)
-      end
-    end
-  end
-
   describe "nested objects inside lists" do
     class NestedInputObjectSchema < GraphQL::Schema
       class ItemInput < GraphQL::Schema::InputObject
@@ -861,7 +807,7 @@ describe GraphQL::Schema::InputObject do
     let(:input_object) { Dummy::DairyProductInput }
 
     def validate_isolated_input(t, input)
-      t.validate_input(input, GraphQL::Query::NullContext)
+      t.validate_input(input, GraphQL::Query::NullContext.instance)
     end
 
     describe "input validation" do
@@ -1198,4 +1144,140 @@ describe GraphQL::Schema::InputObject do
       assert_equal ["No object found for `id: \"1\"`"], res["errors"].map { |e| e["message"] }
     end
   end
+
+  describe "@oneOf" do
+    class OneOfSchema < GraphQL::Schema
+      class OneOfInput < GraphQL::Schema::InputObject
+        one_of
+        argument :arg_1, Int, required: false
+        argument :arg_2, Int, required: false
+      end
+
+      class Query < GraphQL::Schema::Object
+        field :f, String do
+          argument :a, OneOfInput
+        end
+
+        def f(a:)
+          "Got: #{a.values.first}"
+        end
+      end
+      query(Query)
+    end
+
+    it "prints in the SDL" do
+      sdl = OneOfSchema.to_definition
+      assert_includes sdl, "input OneOfInput @oneOf {\n"
+      assert_includes sdl, "directive @oneOf on INPUT_OBJECT"
+    end
+
+    it "shows in the introspection query" do
+      res = OneOfSchema.execute("{ __type(name: \"OneOfInput\") { isOneOf } }")
+      assert_equal true, res["data"]["__type"]["isOneOf"]
+    end
+
+    it "is inherited" do
+      subclass = Class.new(OneOfSchema::OneOfInput)
+      assert subclass.one_of?
+    end
+
+    it "doesn't work without required: false" do
+      err1 = assert_raises ArgumentError do
+        Class.new(GraphQL::Schema::InputObject) do
+          graphql_name "OneOfThing"
+          argument :arg_1, GraphQL::Types::Int
+          one_of
+        end
+      end
+
+      assert_equal "`one_of` may not be used with required arguments -- add `required: false` to argument definitions to use `one_of`", err1.message
+
+      err2 = assert_raises ArgumentError do
+        Class.new(GraphQL::Schema::InputObject) do
+          graphql_name "OneOfThing"
+          one_of
+          argument :arg_2, GraphQL::Types::Int
+        end
+      end
+
+      assert_equal "Argument 'OneOfThing.arg2' must be nullable because it is part of a OneOf type, add `required: false`.", err2.message
+    end
+
+    it "allows queries with only one value" do
+      res = OneOfSchema.execute("{ f(a: { arg1: 5 }) }")
+      assert_equal "Got: 5", res["data"]["f"]
+
+      res = OneOfSchema.execute("{ f(a: { arg2: 8 }) }")
+      assert_equal "Got: 8", res["data"]["f"]
+
+      q_str = "query($args: OneOfInput!) { f(a: $args) }"
+      res = OneOfSchema.execute(q_str, variables: { args: { arg1: 9 } })
+      assert_equal "Got: 9", res["data"]["f"]
+
+      res = OneOfSchema.execute(q_str, variables: { args: { arg2: 10 } })
+      assert_equal "Got: 10", res["data"]["f"]
+    end
+
+    it "rejects queries with multiple values" do
+      res = OneOfSchema.execute("{ f(a: { arg1: 5 , arg2: 4 }) }")
+      assert_equal ["OneOf Input Object 'OneOfInput' must specify exactly one key."], res["errors"].map { |e| e["message"] }
+
+      res = OneOfSchema.execute("{ f(a: {}) }")
+      assert_equal ["OneOf Input Object 'OneOfInput' must specify exactly one key."], res["errors"].map { |e| e["message"] }
+
+      res = OneOfSchema.execute("{ f(a: { arg1: 5 , arg2: null }) }")
+      assert_equal ["OneOf Input Object 'OneOfInput' must specify exactly one key."], res["errors"].map { |e| e["message"] }
+
+      res = OneOfSchema.execute("query($arg2: Int!) { f(a: { arg1: 5 , arg2: $arg2 }) }", variables: { arg2: nil })
+      assert_equal ["OneOf Input Object 'OneOfInput' must specify exactly one key."], res["errors"].map { |e| e["message"] }
+
+
+      res = OneOfSchema.execute("{ f(a: { arg2: null }) }")
+      assert_equal ["Argument 'OneOfInput.arg2' must be non-null."], res["errors"].map { |e| e["message"] }
+
+
+      q_str = "query($args: OneOfInput!) { f(a: $args) }"
+      res = OneOfSchema.execute(q_str, variables: { args: { arg1: 1, arg2: 2 } })
+      assert_equal ["'OneOfInput' requires exactly one argument, but 2 were provided."], res["errors"].map { |e| e["extensions"]["problems"].map { |p| p["explanation"] } }.flatten
+
+      res = OneOfSchema.execute(q_str, variables: { args: { arg1: nil, arg2: 2 } })
+      assert_equal ["'OneOfInput' requires exactly one argument, but 2 were provided."], res["errors"].map { |e| e["extensions"]["problems"].map { |p| p["explanation"] } }.flatten
+
+      res = OneOfSchema.execute(q_str, variables: { args: { arg1: nil } })
+      assert_equal ["'OneOfInput' requires exactly one argument, but 'arg1' was `null`."], res["errors"].map { |e| e["extensions"]["problems"].map { |p| p["explanation"] } }.flatten
+    end
+
+    it "works with a subclass" do
+      one_of_object_class = Class.new(GraphQL::Schema::InputObject) do
+        one_of
+
+        def self.member(*args, **kwargs, &block)
+          argument(*args, required: false, **kwargs, &block)
+        end
+      end
+
+      one_of_concrete_class = Class.new(one_of_object_class) do
+        graphql_name "OneOfInput"
+        member :a, Integer
+        member :b, Integer
+      end
+
+      assert one_of_concrete_class.one_of?
+      refute one_of_concrete_class.arguments["a"].type.non_null?
+
+      query_type = Class.new(GraphQL::Schema::Object) do
+        graphql_name "Query"
+        field :f, Integer do
+          argument :i, one_of_concrete_class
+        end
+      end
+
+      schema = Class.new(GraphQL::Schema) do
+        query(query_type)
+      end
+
+      schema_sdl = schema.to_definition
+      assert_includes schema_sdl, "input OneOfInput @oneOf {\n"
+    end
+  end
 end
