@@ -32,7 +32,6 @@ describe GraphQL::Schema::RelayClassicMutation do
         graphql_name "Test"
       end
       assert_equal mutation, mutation.input_type.mutation
-      assert_equal mutation, mutation.input_type.graphql_definition(silence_deprecation_warning: true).mutation
     end
   end
 
@@ -52,7 +51,8 @@ describe GraphQL::Schema::RelayClassicMutation do
         graphql_name "SomeMutation"
       end
 
-      assert_equal "Parameters for SomeMutation", mutation.field_options[:arguments][:input][:description]
+      field = GraphQL::Schema::Field.new(name: "blah", resolver_class: mutation)
+      assert_equal "Parameters for SomeMutation", field.get_argument("input").description
     end
   end
 
@@ -71,7 +71,6 @@ describe GraphQL::Schema::RelayClassicMutation do
         }
       }
       GRAPHQL
-
       assert_equal "Sitar", res["data"]["addSitar"]["instrument"]["name"]
     end
 
