@@ -1,6 +1,5 @@
 # frozen_string_literal: true
 require "spec_helper"
-include ErrorBubblingHelpers
 
 module MaskHelpers
   def self.build_mask(only:, except:)
@@ -774,39 +773,17 @@ describe GraphQL::Schema::Warden do
       assert_equal expected_errors, error_messages(res)
     end
 
-    describe "with error bubbling disabled" do
-      it "isn't a valid literal input" do
-        without_error_bubbling(MaskHelpers::Schema) do
-          query_string = %|
-          {
-            languages(within: {latitude: 1.0, longitude: 2.2, miles: 3.3}) { name }
-          }|
-          res = MaskHelpers.query_with_mask(query_string, mask)
-          expected_errors =
-            [
-              "InputObject 'WithinInput' doesn't accept argument 'miles'"
-            ]
-          assert_equal expected_errors, error_messages(res)
-        end
-      end
-    end
-
-    describe "with error bubbling enabled" do
-      it "isn't a valid literal input" do
-        with_error_bubbling(MaskHelpers::Schema) do
-          query_string = %|
-          {
-          languages(within: {latitude: 1.0, longitude: 2.2, miles: 3.3}) { name }
-          }|
-          res = MaskHelpers.query_with_mask(query_string, mask)
-          expected_errors =
-            [
-              "InputObject 'WithinInput' doesn't accept argument 'miles'",
-              "Argument 'within' on Field 'languages' has an invalid value ({latitude: 1.0, longitude: 2.2, miles: 3.3}). Expected type 'WithinInput'.",
-            ]
-          assert_equal expected_errors, error_messages(res)
-        end
-      end
+    it "isn't a valid literal input" do
+      query_string = %|
+      {
+        languages(within: {latitude: 1.0, longitude: 2.2, miles: 3.3}) { name }
+      }|
+      res = MaskHelpers.query_with_mask(query_string, mask)
+      expected_errors =
+        [
+          "InputObject 'WithinInput' doesn't accept argument 'miles'"
+        ]
+      assert_equal expected_errors, error_messages(res)
     end
 
     it "isn't a valid variable input" do
