@@ -23,6 +23,9 @@ describe GraphQL::Schema do
       field :some_field, String
     end
 
+    class ExtraType < GraphQL::Schema::Object
+    end
+
     class CustomSubscriptions < GraphQL::Subscriptions::ActionCableSubscriptions
     end
 
@@ -35,17 +38,14 @@ describe GraphQL::Schema do
         max_depth 2
         default_max_page_size 3
         default_page_size 2
-        error_bubbling false
         disable_introspection_entry_points
         orphan_types Jazz::Ensemble
         introspection Module.new
         cursor_encoder Object.new
-        query_execution_strategy Object.new
-        mutation_execution_strategy Object.new
-        subscription_execution_strategy Object.new
         context_class Class.new
         directives [DummyFeature1]
         tracer GraphQL::Tracing::DataDogTracing
+        extra_types ExtraType
         query_analyzer Object.new
         multiplex_analyzer Object.new
         rescue_from(StandardError) { }
@@ -61,15 +61,11 @@ describe GraphQL::Schema do
       assert_equal base_schema.subscription, schema.subscription
       assert_equal base_schema.introspection, schema.introspection
       assert_equal base_schema.cursor_encoder, schema.cursor_encoder
-      assert_equal base_schema.query_execution_strategy, schema.query_execution_strategy
-      assert_equal base_schema.mutation_execution_strategy, schema.mutation_execution_strategy
-      assert_equal base_schema.subscription_execution_strategy, schema.subscription_execution_strategy
       assert_equal base_schema.validate_timeout, schema.validate_timeout
       assert_equal base_schema.max_complexity, schema.max_complexity
       assert_equal base_schema.max_depth, schema.max_depth
       assert_equal base_schema.default_max_page_size, schema.default_max_page_size
       assert_equal base_schema.default_page_size, schema.default_page_size
-      assert_equal base_schema.error_bubbling, schema.error_bubbling
       assert_equal base_schema.orphan_types, schema.orphan_types
       assert_equal base_schema.context_class, schema.context_class
       assert_equal base_schema.directives, schema.directives
@@ -78,15 +74,19 @@ describe GraphQL::Schema do
       assert_equal base_schema.multiplex_analyzers, schema.multiplex_analyzers
       assert_equal base_schema.disable_introspection_entry_points?, schema.disable_introspection_entry_points?
       assert_equal [GraphQL::Backtrace, GraphQL::Subscriptions::ActionCableSubscriptions], schema.plugins.map(&:first)
+      assert_equal [ExtraType], base_schema.extra_types
+      assert_equal [ExtraType], schema.extra_types
       assert_instance_of GraphQL::Subscriptions::ActionCableSubscriptions, schema.subscriptions
       assert_equal GraphQL::Query, schema.query_class
     end
 
     it "can override configuration from its superclass" do
       custom_query_class = Class.new(GraphQL::Query)
+      extra_type_2 = Class.new(GraphQL::Schema::Enum)
       schema = Class.new(base_schema) do
         use CustomSubscriptions, action_cable: nil, action_cable_coder: JSON
         query_class(custom_query_class)
+        extra_types [extra_type_2]
       end
 
       query = Class.new(GraphQL::Schema::Object) do
@@ -108,15 +108,6 @@ describe GraphQL::Schema do
       schema.introspection(introspection)
       cursor_encoder = Object.new
       schema.cursor_encoder(cursor_encoder)
-      query_execution_strategy = Object.new
-      schema.query_execution_strategy(query_execution_strategy)
-      mutation_execution_strategy = Object.new
-      schema.mutation_execution_strategy(mutation_execution_strategy)
-      subscription_execution_strategy = Object.new
-      schema.subscription_execution_strategy(subscription_execution_strategy)
-      assert_equal query_execution_strategy, schema.query_execution_strategy
-      assert_equal mutation_execution_strategy, schema.mutation_execution_strategy
-      assert_equal subscription_execution_strategy, schema.subscription_execution_strategy
 
       context_class = Class.new
       schema.context_class(context_class)
@@ -125,7 +116,6 @@ describe GraphQL::Schema do
       schema.max_depth(20)
       schema.default_max_page_size(30)
       schema.default_page_size(15)
-      schema.error_bubbling(true)
       schema.orphan_types(Jazz::InstrumentType)
       schema.directives([DummyFeature2])
       query_analyzer = Object.new
@@ -147,7 +137,6 @@ describe GraphQL::Schema do
       assert_equal 20, schema.max_depth
       assert_equal 30, schema.default_max_page_size
       assert_equal 15, schema.default_page_size
-      assert schema.error_bubbling
       assert_equal [Jazz::Ensemble, Jazz::InstrumentType], schema.orphan_types
       assert_equal schema.directives, GraphQL::Schema.default_directives.merge(DummyFeature1.graphql_name => DummyFeature1, DummyFeature2.graphql_name => DummyFeature2)
       assert_equal base_schema.query_analyzers + [query_analyzer], schema.query_analyzers
@@ -158,7 +147,7 @@ describe GraphQL::Schema do
       assert_equal [GraphQL::Tracing::DataDogTracing, GraphQL::Tracing::NewRelicTracing], schema.tracers
       assert_includes schema.new_trace.class.ancestors, GraphQL::Tracing::CallLegacyTracers
       assert_equal custom_query_class, schema.query_class
-
+      assert_equal [ExtraType, extra_type_2], schema.extra_types
       assert_instance_of CustomSubscriptions, schema.subscriptions
     end
   end
@@ -238,13 +227,12 @@ describe GraphQL::Schema do
       end
     end
 
-    class NoOpInstrumentation
-      def before_query(query)
-        query.context[:no_op_instrumentation_ran_before_query] = true
-      end
-
-      def after_query(query)
-        query.context[:no_op_instrumentation_ran_after_query] = true
+    module NoOpTrace
+      def execute_query(query:)
+        query.context[:no_op_trace_ran_before_query] = true
+        super
+      ensure
+        query.context[:no_op_trace_ran_after_query] = true
       end
     end
 
@@ -265,7 +253,7 @@ describe GraphQL::Schema do
 
     module PluginWithInstrumentationTracingAndAnalyzer
       def self.use(schema_defn)
-        schema_defn.instrument :query, NoOpInstrumentation.new
+        schema_defn.trace_with(NoOpTrace)
         schema_defn.tracer NoOpTracer.new
         schema_defn.query_analyzer NoOpAnalyzer
       end
@@ -291,8 +279,8 @@ describe GraphQL::Schema do
         res = query.result
         assert res.key?("data")
 
-        assert_equal true, query.context[:no_op_instrumentation_ran_before_query]
-        assert_equal true, query.context[:no_op_instrumentation_ran_after_query]
+        assert_equal true, query.context[:no_op_trace_ran_before_query]
+        assert_equal true, query.context[:no_op_trace_ran_after_query]
         assert_equal true, query.context[:no_op_tracer_ran]
         assert_equal true, query.context[:no_op_analyzer_ran_initialize]
         assert_equal true, query.context[:no_op_analyzer_ran_on_leave_field]
@@ -318,8 +306,8 @@ describe GraphQL::Schema do
         res = query.result
         assert res.key?("data")
 
-        assert_equal true, query.context[:no_op_instrumentation_ran_before_query]
-        assert_equal true, query.context[:no_op_instrumentation_ran_after_query]
+        assert_equal true, query.context[:no_op_trace_ran_before_query]
+        assert_equal true, query.context[:no_op_trace_ran_after_query]
         assert_equal true, query.context[:no_op_tracer_ran]
         assert_equal true, query.context[:no_op_analyzer_ran_initialize]
         assert_equal true, query.context[:no_op_analyzer_ran_on_leave_field]
