@@ -30,10 +30,12 @@ class GraphQLGeneratorsObjectGeneratorTest < BaseGeneratorTest
     ]
 
     expected_content = <<-RUBY
+# frozen_string_literal: true
+
 module Types
   class BirdType < Types::BaseObject
     field :wingspan, Integer, null: false
-    field :foliage, [Types::ColorType], null: true
+    field :foliage, [Types::ColorType]
   end
 end
 RUBY
@@ -45,11 +47,41 @@ RUBY
     end
   end
 
-  test "it generates classifed file" do
-    run_generator(["page"])
-    assert_file "app/graphql/types/page_type.rb", <<-RUBY
+  test "it generates fields with namespaced types" do
+    commands = [
+      # GraphQL-style:
+      ["Bird", "wingspan:Int!", "foliage:[Color]"],
+      # Ruby-style:
+      ["BirdType", "wingspan:!Integer", "foliage:[Types::ColorType]"],
+      # Mixed
+      ["BirdType", "wingspan:!Int", "foliage:[Color]"],
+    ].map { |c| c + ["--namespaced-types"]}
+
+    expected_content = <<-RUBY
+# frozen_string_literal: true
+
 module Types
-  class PageType < Types::BaseObject
+  class Objects::BirdType < Types::BaseObject
+    field :wingspan, Integer, null: false
+    field :foliage, [Types::ColorType]
+  end
+end
+RUBY
+
+    commands.each do |c|
+      prepare_destination
+      run_generator(c)
+      assert_file "app/graphql/types/objects/bird_type.rb", expected_content
+    end
+  end
+
+  test "it generates namespaced classifed file" do
+    run_generator(["books/page"])
+    assert_file "app/graphql/types/books/page_type.rb", <<-RUBY
+# frozen_string_literal: true
+
+module Types
+  class Books::PageType < Types::BaseObject
   end
 end
 RUBY
@@ -58,22 +90,26 @@ RUBY
   test "it makes Relay nodes" do
     run_generator(["Page", "--node"])
     assert_file "app/graphql/types/page_type.rb", <<-RUBY
+# frozen_string_literal: true
+
 module Types
   class PageType < Types::BaseObject
-    implements GraphQL::Relay::Node.interface
+    implements GraphQL::Types::Relay::Node
   end
 end
 RUBY
   end
 
-  test "it generates objects based on ActiveRecord schema" do
-    run_generator(["TestUser"])
-    assert_file "app/graphql/types/test_user_type.rb", <<-RUBY
+  test "it generates objects based on ActiveRecord schema, with namespaced types" do
+    run_generator(["TestUser", "--namespaced-types"])
+    assert_file "app/graphql/types/objects/test_user_type.rb", <<-RUBY
+# frozen_string_literal: true
+
 module Types
-  class TestUserType < Types::BaseObject
+  class Objects::TestUserType < Types::BaseObject
     field :id, ID, null: false
-    field :created_at, GraphQL::Types::ISO8601DateTime, null: true
-    field :birthday, GraphQL::Types::ISO8601Date, null: true
+    field :created_at, GraphQL::Types::ISO8601DateTime
+    field :birthday, GraphQL::Types::ISO8601Date
     field :points, Integer, null: false
     field :rating, Float, null: false
   end
@@ -82,16 +118,20 @@ RUBY
   end
 
   test "it generates objects based on ActiveRecord schema with additional custom fields" do
-    run_generator(["TestUser", "name:!String"])
+    run_generator(["TestUser", "name:!String", "email:!Citext", "settings:jsonb"])
     assert_file "app/graphql/types/test_user_type.rb", <<-RUBY
+# frozen_string_literal: true
+
 module Types
   class TestUserType < Types::BaseObject
     field :id, ID, null: false
-    field :created_at, GraphQL::Types::ISO8601DateTime, null: true
-    field :birthday, GraphQL::Types::ISO8601Date, null: true
+    field :created_at, GraphQL::Types::ISO8601DateTime
+    field :birthday, GraphQL::Types::ISO8601Date
     field :points, Integer, null: false
     field :rating, Float, null: false
     field :name, String, null: false
+    field :email, String, null: false
+    field :settings, GraphQL::Types::JSON
   end
 end
 RUBY
